==> cv-generator-fe-1.19.1.tgz: package/src/app/components/language/language.component.ts <==
import { Component, AfterViewInit } from '@angular/core';
import { PropertyComponent } from '../property/property.component';
import { PortfolioService } from '../../services/portfolio/portfolio.service';
import { InputService } from '../../services/input/input.service';
import { UiService } from '../../services/ui/ui.service';
import { DataService } from '../../services/data/data.service';
import { ExcelDateFormatterService } from '../../services/excel-date-formatter/excel-date-formatter.service';
import { Params } from '../../services/component-outlet-injector/params';
import { ChartService } from '../../services/chart/chart.service';

/**
 * Language component.
 * ~extends {@link PropertyComponent}
 * ~implements {@link AfterViewInit}
 */
@Component({
  selector: 'app-language',
  templateUrl: './language.component.html',
  styleUrls: ['./language.component.scss']
})
export class LanguageComponent extends PropertyComponent implements AfterViewInit {
  /**
   * Constructs a Language component.
   * ~constructor
   * @param chartService The chart service injected dependency.
   * @param portfolioService The portfolio service injected dependency.
   * @param inputService The input service injected dependency.
   * @param uiService The ui service injected dependency.
   * @param dataService The data service injected dependency.
   * @param excelDateFormatterService The Excel date formatter service injected dependency.
   * @param params The inherited injector params injected dependency.
   */
  constructor(
    private chartService: ChartService,
    public portfolioService: PortfolioService,
    public inputService: InputService,
    public uiService: UiService,
    public dataService: DataService,
    public excelDateFormatterService: ExcelDateFormatterService,
    public params?: Params) {
    super(portfolioService, inputService, uiService, dataService, excelDateFormatterService, params);
  }

  /** Initialization */
  ngAfterViewInit() {
    this.Initialize();
  }

  /** Initialization */
  Initialize() {
    this.drawLanguageChart();
  }

  /** Draws a language chart */
  private drawLanguageChart() {
    if (typeof this.portfolioService.cv !== 'undefined' && this.portfolioService.cv != null) {
      const chartType = 'Language';
      const data = this.portfolioService.cv.Languages;

      this.chartService.drawChart(chartType, this.chartService.addLanguageChart(data));
    }
  }
}

==> cv-generator-fe-1.29.1.tgz: package/src/app/components/language/language.component.ts <==
import { Component, AfterViewInit, OnInit, OnDestroy } from '@angular/core';
import { Subscription } from 'rxjs';

import { PropertyComponent } from '../property/property.component';
import { PortfolioService } from '../../services/portfolio/portfolio.service';
import { InputService } from '../../services/input/input.service';
import { UiService } from '../../services/ui/ui.service';
import { DataService } from '../../services/data/data.service';
import { ExcelDateFormatterService } from '../../services/excel-date-formatter/excel-date-formatter.service';
import { Params } from '../../services/component-outlet-injector/params';
import { ChartService } from '../../services/chart/chart.service';

/**
 * Language component.
 * ~extends {@link PropertyComponent}
 * ~implements {@link OnInit}
 * ~implements {@link OnDestroy}
 * ~implements {@link AfterViewInit}
 */
@Component({
  selector: 'app-language',
  templateUrl: './language.component.html',
  styleUrls: ['./language.component.scss']
})
export class LanguageComponent extends PropertyComponent implements OnInit, OnDestroy, AfterViewInit {
  /** Responsive modelChanged subscription. */
  private responsiveModelChanged: Subscription | undefined;

  /**
   * Constructs a Language component.
   * ~constructor
   *
   * @param chartService The chart service injected dependency.
   * @param portfolioService The portfolio service injected dependency.
   * @param inputService The input service injected dependency.
   * @param uiService The ui service injected dependency.
   * @param dataService The data service injected dependency.
   * @param excelDateFormatterService The Excel date formatter service injected dependency.
   * @param params The inherited injector params injected dependency.
   */
  constructor(
    private chartService: ChartService,
    public portfolioService: PortfolioService,
    public inputService: InputService,
    public uiService: UiService,
    public dataService: DataService,
    public excelDateFormatterService: ExcelDateFormatterService,
    public params?: Params) {
    super(portfolioService, inputService, uiService, dataService, excelDateFormatterService, params);
  }

  /** Subscription */
  ngOnInit() {
    this.responsiveModelChanged = this.portfolioService.toolbarService.responsiveModelChanged$.subscribe(
      (_: { sourceEntityKey: string, value: boolean }) => this.onResponsiveToggled(_));
  }

  /** Cleanup */
  ngOnDestroy() {
    this.responsiveModelChanged?.unsubscribe();
  }

  /** Initialization */
  ngAfterViewInit() {
    this.Initialize();
  }

  /** Initialization */
  Initialize() {
    this.drawLanguageChart();
  }

  /** Draws a language chart */
  private drawLanguageChart() {
    if (typeof this.portfolioService.model.portfolioModel.cv !== 'undefined' && this.portfolioService.model.portfolioModel.cv != null) {
      const chartType = 'Language';
      const data = this.portfolioService.model.portfolioModel.cv.Languages;

      this.chartService.chartModel.chartLoaded[chartType] = false;
      this.chartService.drawChart(chartType,
        this.chartService.addLanguageChart(data, this.portfolioService.toolbarService.responsive('Languages Chart')));
    }
  }

  /** Responsive toggled event handler. */
  private onResponsiveToggled(event: { sourceEntityKey: string, value: boolean }) {
    if (event.sourceEntityKey !== 'Languages Chart') { return; }

    this.drawLanguageChart();
  }
}
